the sampling rate, an integer between 1000 and 48000.
bits
the sampling quality in bits per sample, 8 or 16.
channels
1 for mono, or 2 for stereo.
reverse
logical. If TRUE, the waveform will be mirrored vertically.
upPerc
a number between 0 and 100 giving the percentage of the waveform with value +1.
Value
a Sample object.
Details
If channels=2, left and right side of the sample will be the same for Sine, Sawtooth and Square. For Noise, both sides will be generated separately, using runif.